sfs.fd.sdm
==========

.. automodule:: sfs.fd.sdm

   
   
   .. rubric:: Functions

   .. autosummary::
   
      line_2d
      plane_25d
      plane_2d
      point_25d
   
   

   
   
   

   
   
   